Index: tools/testing/dart/test_runner.dart |
diff --git a/tools/testing/dart/test_runner.dart b/tools/testing/dart/test_runner.dart |
index 93c38e98f844924b5a8b20a76bcdea74f4ebb52b..271de3e55a3c24ae94fa48531074fb36f76621e1 100644 |
--- a/tools/testing/dart/test_runner.dart |
+++ b/tools/testing/dart/test_runner.dart |
@@ -180,20 +180,20 @@ class CompilationCommand extends Command { |
} |
} |
-class DumpRenderTreeCommand extends Command { |
+class ContentShellCommand extends Command { |
/** |
* If [expectedOutputPath] is set, the output of DumpRenderTree is compared |
* with the content of [expectedOutputPath]. |
* This is used for example for pixel tests, where [expectedOutputPath] points |
* to a *png file. |
*/ |
io.Path expectedOutputPath; |
- DumpRenderTreeCommand(String executable, |
- String htmlFile, |
- List<String> options, |
- List<String> dartFlags, |
- io.Path this.expectedOutputPath) |
+ ContentShellCommand(String executable, |
+ String htmlFile, |
+ List<String> options, |
+ List<String> dartFlags, |
+ io.Path this.expectedOutputPath) |
: super(executable, |
_getArguments(options, htmlFile), |
_getEnvironment(dartFlags)); |
@@ -645,7 +645,7 @@ class BrowserCommandOutputImpl extends CommandOutputImpl { |
} |
if (command.expectedOutputFile != null) { |
// We are either doing a pixel test or a layout test with DumpRenderTree |
return _failedBecauseOfUnexpectedDRTOutput; |
} |
return _browserTestFailure; |
@@ -653,10 +653,10 @@ class BrowserCommandOutputImpl extends CommandOutputImpl { |
bool get _failedBecauseOfMissingXDisplay { |
// Browser case: |
// If the browser test failed, it may have been because DumpRenderTree |
// and the virtual framebuffer X server didn't hook up, or DRT crashed with |
// a core dump. Sometimes DRT crashes after it has set the stdout to PASS, |
// so we have to do this check first. |
var stderrLines = decodeUtf8(super.stderr).split("\n"); |
for (String line in stderrLines) { |
// TODO(kustermann,ricow): Issue: 7564 |
@@ -677,7 +677,7 @@ class BrowserCommandOutputImpl extends CommandOutputImpl { |
bool get _failedBecauseOfUnexpectedDRTOutput { |
/* |
* The output of DumpRenderTree is different for pixel tests than for |
* layout tests. |
* |
* On a pixel test, the DRT output has the following format |
@@ -180,20 +180,20 @@ class CompilationCommand extends Command { |
/** |
- * If [expectedOutputPath] is set, the output of DumpRenderTree is compared |
+ * If [expectedOutputPath] is set, the output of content shell is compared |
* with the content of [expectedOutputPath]. |
* This is used for example for pixel tests, where [expectedOutputPath] points |
@@ -645,7 +645,7 @@ class BrowserCommandOutputImpl extends CommandOutputImpl { |
} |
if (command.expectedOutputFile != null) { |
- // We are either doing a pixel test or a layout test with DumpRenderTree |
+ // We are either doing a pixel test or a layout test with content shell |
return _failedBecauseOfUnexpectedDRTOutput; |
} |
@@ -653,10 +653,10 @@ class BrowserCommandOutputImpl extends CommandOutputImpl { |
bool get _failedBecauseOfMissingXDisplay { |
// Browser case: |
- // If the browser test failed, it may have been because DumpRenderTree |
- // and the virtual framebuffer X server didn't hook up, or DRT crashed with |
- // a core dump. Sometimes DRT crashes after it has set the stdout to PASS, |
- // so we have to do this check first. |
+ // If the browser test failed, it may have been because content shell |
+ // and the virtual framebuffer X server didn't hook up, or it crashed with |
+ // a core dump. Sometimes content shell crashes after it has set the stdout |
+ // to PASS, so we have to do this check first. |
var stderrLines = decodeUtf8(super.stderr).split("\n"); |
for (String line in stderrLines) { |
@@ -677,7 +677,7 @@ class BrowserCommandOutputImpl extends CommandOutputImpl { |
bool get _failedBecauseOfUnexpectedDRTOutput { |
/* |
- * The output of DumpRenderTree is different for pixel tests than for |
+ * The output of content shell is different for pixel tests than for |
* layout tests. |
* |